#!/usr/bin/env python3

import argparse
import sys
import sufpref


def get_args():
    parser = argparse.ArgumentParser(
        usage='%(prog)s [OPTIONS]',
        description='Suffix-prefix task',
        epilog="Author: Samun Victor <victor.samun@gmail.com>",
        prefix_chars='-/')
    parser.add_argument(
        '-a', '--algo',
        choices=['bruteforce', 'hash'],
        default='hash',
        help='algorithm selector')
    parser.add_argument(
        '-d', '--dublicates',
        action='store_true',
        help='remove dublicates from input')
    parser.add_argument(
        '-f', '--file',
        type=argparse.FileType('r'),
        default=sys.stdin,
        help='input file')
    return parser.parse_args()


def main():
    args = get_args()

    data = [line.strip() for line in args.file]
    algo = {
        'bruteforce': sufpref.solve_bf,
        'hash': sufpref.solve_hash
    }[args.algo]

    print(algo(data, args.dublicates))

if __name__ == '__main__':
    main()
